function [fobj,g] = objetivo(X,degrau,y,tempo,modelo)


tfinal=tempo(length(tempo)); %pega o ultimo instante de tempo
fobj=0; %zera a variavel fobj


% EQUACAO:
%     (perturbacao degrau) * modelo

if modelo == 1  
   % MODELO: PRIMEIRA ORDEM MAIS TEMPO MORTO (LINHA G, tabela 121)   
   %          1       Ganho        -TM*s
   %   Y(s)= ---  [ ------------  e         ]
   %          s      (Tau*s+1)
   %
   % ilaplace( (1/s)*(k/(tau1*s+1)))
   
   Tau    = X(1);
   Ganho  = X(2);
   Tmorto = X(3);
   t=max(0,(tempo-Tmorto));
   ycalc  = degrau*Ganho*(1-exp(-t/Tau));
   
   
elseif modelo == 2 
   % MODELO: LEAD LAG COM TEMPO MORTO  (LINHA P, tabela 121)
   %          1             (Tau1*s+1)       -TM*s
   %   Y(s)= ---  Ganho ------------------- e
   %          s             (Tau2*s+1)
   %
   % ilaplace((1/s)*(tau1*s+1)/(tau2*s+1))
   Tau1   = X(1);
   Tau2   = X(2);
   Ganho  = X(3);
   Tmorto = X(4);
   RO=Tau1/Tau2;
   t=max(0,(tempo-Tmorto));
   ycalc = degrau*Ganho*(1 - (1-RO)*exp(-t/Tau2));
                        
   
elseif modelo == 3 
   % MODELO: SEGUNDA ORDEM COM TEMPO MORTO (LINHA Q, tabela 121)
   %         1                  1             -TM*s
   %   Y(s)=---   Ganho -------------------- e
   %         s          (Tau1*s+1)(Tau2*s+1)
   
   Tau1   = X(1);
   Tau2   = X(2);
   Ganho  = X(3);
   Tmorto = X(4);
   t=max(0,(tempo-Tmorto));
   if Tau1 == Tau2
      Tau = Tau1;
	   ycalc  = degrau*Ganho*(1-exp(-t/Tau)-(exp(-t/Tau))/Tau);
   else   
      ycalc=degrau*Ganho/(Tau2-Tau1)*...
         ((Tau2-Tau1)+Tau1*exp(-t/Tau1)-Tau2*exp(-t/Tau2));
   end

   
elseif modelo == 4
   % MODELO: 1 POLO, DOIS ZEROS COM TEMPO MORTO (LINHA K, tabela 121)
   %         1           (Tau3*s+1)         -TM*s
   %   Y(s)=---  K ----------------------- e
   %         s       (Tau1*s+1)(Tau2*s+1)
   
   Tau1   = X(1);
   Tau2   = X(2);
   Tau3   = X(3); 
   Ganho  = X(4);
   Tmorto = X(5);
   t=max(0,(tempo-Tmorto));
   if Tau1 == Tau2
      fobj=10000000;
      g=[];
      return
   end
   ycalc=Ganho*degrau*(1-((Tau1-Tau3)./(Tau1-Tau2)).*exp(-t./Tau1)-...
      ((Tau2-Tau3)./(Tau2-Tau1)).*exp(-t./Tau2));
  
   
   
elseif modelo == 5
   % MODELO: PRIMEIRA ORDEM (LINHA A, Tabela 121)        
   %          1     Ganho     
   %   Y(s)= --- ------------
   %          s     (Tau*s+1)
   %  ilaplace((1/s)*(k/(tau*s+1)))
   
    Tau    = X(1);
    Ganho  = X(2);
    ycalc  = degrau*Ganho*(1-exp(-tempo/Tau));
    
     
    
elseif modelo == 6
    %MODELO INTEGRADOR (Linha E, tabela 121)
    %ilaplace((1/s)*(k/s))
    
    Ganho =  X(1);
    ycalc =  degrau*Ganho*tempo;
    
    
    
elseif modelo == 7
    %MODELO INTEGRADOR COM TEMPO MORTO (Linha M, tabela 121)
    %ilaplace((1/s)*(k/s))
    
    Ganho  = X(1);
    Tmorto = X(2);
    t=max(0,(tempo-Tmorto));
    ycalc  =  degrau*Ganho*t;
    
    
    
elseif modelo == 8        
    %Linha O, tabela 121
        
    Ganho  = X(1);
    Tau    = X(2);
    Tmorto = X(3);
    t=max(0,(tempo-Tmorto));
    ycalc  = degrau*Ganho*t*(1/Tau)*exp(-t/Tau);
                     
    
elseif modelo == 9       
    %Linha F, tabela 121
    Ganho = X(1);
    Tau = X(2);
    ycalc=degrau*Ganho*tempo*(1/Tau)*exp(-tempo/Tau);
   
    
    
else
    %Linha B, tabela 121  
    Ganho = X(1);
    Tau1  = X(2);
    Tau2  = X(3);
    ycalc = degrau*Ganho*(1-exp(-tempo/Tau1))*(1/Tau2)*exp(-tempo/Tau2);
    
                     
end


%Calculo do erro (diferena entre o valor experimental e o valor calculado)
fobj=(y-ycalc)'*(y-ycalc);
g=[];

%Grafico de acompanhamento do ajuste
plot(tempo,y,'*',tempo,ycalc,'m')
title(['X = [' num2str(X) '];  FObj = ' num2str(fobj)] )
drawnow



